# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import DnsRecordStatus
from .types import DnsRecordType
from .types import DnsRecordsStatus
from .types import DomainAction
from .types import DomainAvailabilityAction
from .types import DomainAvailabilityStatus
from .content import DOMAIN_AVAILABILITY_TRANSIENT_STATUSES
from .types import DomainDnsAction
from .types import DomainStatus
from .content import DOMAIN_TRANSIENT_STATUSES
from .types import DomainZoneOwner
from .types import HostingStatus
from .content import HOSTING_TRANSIENT_STATUSES
from .types import ListDatabaseUsersRequestOrderBy
from .types import ListDatabasesRequestOrderBy
from .types import ListFtpAccountsRequestOrderBy
from .types import ListHostingsRequestOrderBy
from .types import ListMailAccountsRequestOrderBy
from .types import ListOffersRequestOrderBy
from .types import ListWebsitesRequestOrderBy
from .types import NameserverStatus
from .types import OfferOptionName
from .types import OfferOptionWarning
from .types import PlatformPlatformGroup
from .types import PlatformControlPanelUrls
from .types import OfferOption
from .types import PlatformControlPanel
from .types import CreateDatabaseRequestUser
from .types import AutoConfigDomainDns
from .types import CreateHostingRequestDomainConfiguration
from .types import OfferOptionRequest
from .types import SyncDomainDnsRecordsRequestRecord
from .types import DnsRecord
from .types import Nameserver
from .types import HostingUser
from .types import Offer
from .types import Platform
from .types import ControlPanel
from .types import DatabaseUser
from .types import Database
from .types import FtpAccount
from .types import HostingSummary
from .types import MailAccount
from .types import Website
from .types import DomainAvailability
from .types import CheckUserOwnsDomainResponse
from .types import ControlPanelApiListControlPanelsRequest
from .types import DatabaseApiAssignDatabaseUserRequest
from .types import DatabaseApiChangeDatabaseUserPasswordRequest
from .types import DatabaseApiCreateDatabaseRequest
from .types import DatabaseApiCreateDatabaseUserRequest
from .types import DatabaseApiDeleteDatabaseRequest
from .types import DatabaseApiDeleteDatabaseUserRequest
from .types import DatabaseApiGetDatabaseRequest
from .types import DatabaseApiGetDatabaseUserRequest
from .types import DatabaseApiListDatabaseUsersRequest
from .types import DatabaseApiListDatabasesRequest
from .types import DatabaseApiUnassignDatabaseUserRequest
from .types import DnsApiCheckUserOwnsDomainRequest
from .types import DnsApiGetDomainDnsRecordsRequest
from .types import DnsApiGetDomainRequest
from .types import DnsApiSearchDomainsRequest
from .types import DnsApiSyncDomainDnsRecordsRequest
from .types import DnsRecords
from .types import Domain
from .types import FtpAccountApiChangeFtpAccountPasswordRequest
from .types import FtpAccountApiCreateFtpAccountRequest
from .types import FtpAccountApiListFtpAccountsRequest
from .types import FtpAccountApiRemoveFtpAccountRequest
from .types import Hosting
from .types import HostingApiCreateHostingRequest
from .types import HostingApiCreateSessionRequest
from .types import HostingApiDeleteHostingRequest
from .types import HostingApiGetHostingRequest
from .types import HostingApiGetResourceSummaryRequest
from .types import HostingApiListHostingsRequest
from .types import HostingApiResetHostingPasswordRequest
from .types import HostingApiUpdateHostingRequest
from .types import ListControlPanelsResponse
from .types import ListDatabaseUsersResponse
from .types import ListDatabasesResponse
from .types import ListFtpAccountsResponse
from .types import ListHostingsResponse
from .types import ListMailAccountsResponse
from .types import ListOffersResponse
from .types import ListWebsitesResponse
from .types import MailAccountApiChangeMailAccountPasswordRequest
from .types import MailAccountApiCreateMailAccountRequest
from .types import MailAccountApiListMailAccountsRequest
from .types import MailAccountApiRemoveMailAccountRequest
from .types import OfferApiListOffersRequest
from .types import ResetHostingPasswordResponse
from .types import ResourceSummary
from .types import SearchDomainsResponse
from .types import Session
from .types import WebsiteApiListWebsitesRequest
from .api import WebhostingV1ControlPanelAPI
from .api import WebhostingV1DatabaseAPI
from .api import WebhostingV1DnsAPI
from .api import WebhostingV1OfferAPI
from .api import WebhostingV1HostingAPI
from .api import WebhostingV1FtpAccountAPI
from .api import WebhostingV1MailAccountAPI
from .api import WebhostingV1WebsiteAPI

__all__ = [
    "DnsRecordStatus",
    "DnsRecordType",
    "DnsRecordsStatus",
    "DomainAction",
    "DomainAvailabilityAction",
    "DomainAvailabilityStatus",
    "DOMAIN_AVAILABILITY_TRANSIENT_STATUSES",
    "DomainDnsAction",
    "DomainStatus",
    "DOMAIN_TRANSIENT_STATUSES",
    "DomainZoneOwner",
    "HostingStatus",
    "HOSTING_TRANSIENT_STATUSES",
    "ListDatabaseUsersRequestOrderBy",
    "ListDatabasesRequestOrderBy",
    "ListFtpAccountsRequestOrderBy",
    "ListHostingsRequestOrderBy",
    "ListMailAccountsRequestOrderBy",
    "ListOffersRequestOrderBy",
    "ListWebsitesRequestOrderBy",
    "NameserverStatus",
    "OfferOptionName",
    "OfferOptionWarning",
    "PlatformPlatformGroup",
    "PlatformControlPanelUrls",
    "OfferOption",
    "PlatformControlPanel",
    "CreateDatabaseRequestUser",
    "AutoConfigDomainDns",
    "CreateHostingRequestDomainConfiguration",
    "OfferOptionRequest",
    "SyncDomainDnsRecordsRequestRecord",
    "DnsRecord",
    "Nameserver",
    "HostingUser",
    "Offer",
    "Platform",
    "ControlPanel",
    "DatabaseUser",
    "Database",
    "FtpAccount",
    "HostingSummary",
    "MailAccount",
    "Website",
    "DomainAvailability",
    "CheckUserOwnsDomainResponse",
    "ControlPanelApiListControlPanelsRequest",
    "DatabaseApiAssignDatabaseUserRequest",
    "DatabaseApiChangeDatabaseUserPasswordRequest",
    "DatabaseApiCreateDatabaseRequest",
    "DatabaseApiCreateDatabaseUserRequest",
    "DatabaseApiDeleteDatabaseRequest",
    "DatabaseApiDeleteDatabaseUserRequest",
    "DatabaseApiGetDatabaseRequest",
    "DatabaseApiGetDatabaseUserRequest",
    "DatabaseApiListDatabaseUsersRequest",
    "DatabaseApiListDatabasesRequest",
    "DatabaseApiUnassignDatabaseUserRequest",
    "DnsApiCheckUserOwnsDomainRequest",
    "DnsApiGetDomainDnsRecordsRequest",
    "DnsApiGetDomainRequest",
    "DnsApiSearchDomainsRequest",
    "DnsApiSyncDomainDnsRecordsRequest",
    "DnsRecords",
    "Domain",
    "FtpAccountApiChangeFtpAccountPasswordRequest",
    "FtpAccountApiCreateFtpAccountRequest",
    "FtpAccountApiListFtpAccountsRequest",
    "FtpAccountApiRemoveFtpAccountRequest",
    "Hosting",
    "HostingApiCreateHostingRequest",
    "HostingApiCreateSessionRequest",
    "HostingApiDeleteHostingRequest",
    "HostingApiGetHostingRequest",
    "HostingApiGetResourceSummaryRequest",
    "HostingApiListHostingsRequest",
    "HostingApiResetHostingPasswordRequest",
    "HostingApiUpdateHostingRequest",
    "ListControlPanelsResponse",
    "ListDatabaseUsersResponse",
    "ListDatabasesResponse",
    "ListFtpAccountsResponse",
    "ListHostingsResponse",
    "ListMailAccountsResponse",
    "ListOffersResponse",
    "ListWebsitesResponse",
    "MailAccountApiChangeMailAccountPasswordRequest",
    "MailAccountApiCreateMailAccountRequest",
    "MailAccountApiListMailAccountsRequest",
    "MailAccountApiRemoveMailAccountRequest",
    "OfferApiListOffersRequest",
    "ResetHostingPasswordResponse",
    "ResourceSummary",
    "SearchDomainsResponse",
    "Session",
    "WebsiteApiListWebsitesRequest",
    "WebhostingV1ControlPanelAPI",
    "WebhostingV1DatabaseAPI",
    "WebhostingV1DnsAPI",
    "WebhostingV1OfferAPI",
    "WebhostingV1HostingAPI",
    "WebhostingV1FtpAccountAPI",
    "WebhostingV1MailAccountAPI",
    "WebhostingV1WebsiteAPI",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import CockpitStatus
from .content import COCKPIT_TRANSIENT_STATUSES
from .types import DatasourceType
from .types import GrafanaUserRole
from .types import ListDatasourcesRequestOrderBy
from .types import ListGrafanaUsersRequestOrderBy
from .types import ListPlansRequestOrderBy
from .types import ListTokensRequestOrderBy
from .types import PlanName
from .types import ContactPointEmail
from .types import TokenScopes
from .types import CockpitEndpoints
from .types import Plan
from .types import ContactPoint
from .types import Datasource
from .types import GrafanaProductDashboard
from .types import GrafanaUser
from .types import Token
from .types import ActivateCockpitRequest
from .types import Cockpit
from .types import CockpitMetrics
from .types import CreateContactPointRequest
from .types import CreateDatasourceRequest
from .types import CreateGrafanaUserRequest
from .types import CreateTokenRequest
from .types import DeactivateCockpitRequest
from .types import DeleteContactPointRequest
from .types import DeleteDatasourceRequest
from .types import DeleteGrafanaUserRequest
from .types import DeleteTokenRequest
from .types import DisableManagedAlertsRequest
from .types import EnableManagedAlertsRequest
from .types import GetCockpitMetricsRequest
from .types import GetCockpitRequest
from .types import GetGrafanaProductDashboardRequest
from .types import GetTokenRequest
from .types import ListContactPointsRequest
from .types import ListContactPointsResponse
from .types import ListDatasourcesRequest
from .types import ListDatasourcesResponse
from .types import ListGrafanaProductDashboardsRequest
from .types import ListGrafanaProductDashboardsResponse
from .types import ListGrafanaUsersRequest
from .types import ListGrafanaUsersResponse
from .types import ListPlansRequest
from .types import ListPlansResponse
from .types import ListTokensRequest
from .types import ListTokensResponse
from .types import ResetGrafanaUserPasswordRequest
from .types import SelectPlanRequest
from .types import SelectPlanResponse
from .types import TriggerTestAlertRequest
from .api import CockpitV1Beta1API

__all__ = [
    "CockpitStatus",
    "COCKPIT_TRANSIENT_STATUSES",
    "DatasourceType",
    "GrafanaUserRole",
    "ListDatasourcesRequestOrderBy",
    "ListGrafanaUsersRequestOrderBy",
    "ListPlansRequestOrderBy",
    "ListTokensRequestOrderBy",
    "PlanName",
    "ContactPointEmail",
    "TokenScopes",
    "CockpitEndpoints",
    "Plan",
    "ContactPoint",
    "Datasource",
    "GrafanaProductDashboard",
    "GrafanaUser",
    "Token",
    "ActivateCockpitRequest",
    "Cockpit",
    "CockpitMetrics",
    "CreateContactPointRequest",
    "CreateDatasourceRequest",
    "CreateGrafanaUserRequest",
    "CreateTokenRequest",
    "DeactivateCockpitRequest",
    "DeleteContactPointRequest",
    "DeleteDatasourceRequest",
    "DeleteGrafanaUserRequest",
    "DeleteTokenRequest",
    "DisableManagedAlertsRequest",
    "EnableManagedAlertsRequest",
    "GetCockpitMetricsRequest",
    "GetCockpitRequest",
    "GetGrafanaProductDashboardRequest",
    "GetTokenRequest",
    "ListContactPointsRequest",
    "ListContactPointsResponse",
    "ListDatasourcesRequest",
    "ListDatasourcesResponse",
    "ListGrafanaProductDashboardsRequest",
    "ListGrafanaProductDashboardsResponse",
    "ListGrafanaUsersRequest",
    "ListGrafanaUsersResponse",
    "ListPlansRequest",
    "ListPlansResponse",
    "ListTokensRequest",
    "ListTokensResponse",
    "ResetGrafanaUserPasswordRequest",
    "SelectPlanRequest",
    "SelectPlanResponse",
    "TriggerTestAlertRequest",
    "CockpitV1Beta1API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import AclRuleProtocol
from .types import Action
from .types import ListPrivateNetworksRequestOrderBy
from .types import ListSubnetsRequestOrderBy
from .types import ListVPCsRequestOrderBy
from .types import Subnet
from .types import PrivateNetwork
from .types import Route
from .types import AclRule
from .types import VPC
from .types import AddSubnetsRequest
from .types import AddSubnetsResponse
from .types import CreatePrivateNetworkRequest
from .types import CreateRouteRequest
from .types import CreateVPCRequest
from .types import DeletePrivateNetworkRequest
from .types import DeleteRouteRequest
from .types import DeleteSubnetsRequest
from .types import DeleteSubnetsResponse
from .types import DeleteVPCRequest
from .types import EnableDHCPRequest
from .types import EnableRoutingRequest
from .types import GetAclRequest
from .types import GetAclResponse
from .types import GetPrivateNetworkRequest
from .types import GetRouteRequest
from .types import GetVPCRequest
from .types import ListPrivateNetworksRequest
from .types import ListPrivateNetworksResponse
from .types import ListSubnetsRequest
from .types import ListSubnetsResponse
from .types import ListVPCsRequest
from .types import ListVPCsResponse
from .types import SetAclRequest
from .types import SetAclResponse
from .types import SetSubnetsRequest
from .types import SetSubnetsResponse
from .types import UpdatePrivateNetworkRequest
from .types import UpdateRouteRequest
from .types import UpdateVPCRequest
from .api import VpcV2API

__all__ = [
    "AclRuleProtocol",
    "Action",
    "ListPrivateNetworksRequestOrderBy",
    "ListSubnetsRequestOrderBy",
    "ListVPCsRequestOrderBy",
    "Subnet",
    "PrivateNetwork",
    "Route",
    "AclRule",
    "VPC",
    "AddSubnetsRequest",
    "AddSubnetsResponse",
    "CreatePrivateNetworkRequest",
    "CreateRouteRequest",
    "CreateVPCRequest",
    "DeletePrivateNetworkRequest",
    "DeleteRouteRequest",
    "DeleteSubnetsRequest",
    "DeleteSubnetsResponse",
    "DeleteVPCRequest",
    "EnableDHCPRequest",
    "EnableRoutingRequest",
    "GetAclRequest",
    "GetAclResponse",
    "GetPrivateNetworkRequest",
    "GetRouteRequest",
    "GetVPCRequest",
    "ListPrivateNetworksRequest",
    "ListPrivateNetworksResponse",
    "ListSubnetsRequest",
    "ListSubnetsResponse",
    "ListVPCsRequest",
    "ListVPCsResponse",
    "SetAclRequest",
    "SetAclResponse",
    "SetSubnetsRequest",
    "SetSubnetsResponse",
    "UpdatePrivateNetworkRequest",
    "UpdateRouteRequest",
    "UpdateVPCRequest",
    "VpcV2API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime
from enum import Enum
from typing import List, Optional

from scaleway_core.bridge import (
    Region as ScwRegion,
)
from scaleway_core.utils import (
    StrEnumMeta,
)


class BgpStatus(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_BGP_STATUS = "unknown_bgp_status"
    UP = "up"
    DOWN = "down"

    def __str__(self) -> str:
        return str(self.value)


class LinkStatus(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_LINK_STATUS = "unknown_link_status"
    CONFIGURING = "configuring"
    FAILED = "failed"
    REQUESTED = "requested"
    REFUSED = "refused"
    EXPIRED = "expired"
    PROVISIONING = "provisioning"
    ACTIVE = "active"
    LIMITED_CONNECTIVITY = "limited_connectivity"
    ALL_DOWN = "all_down"
    DEPROVISIONING = "deprovisioning"
    DELETED = "deleted"
    LOCKED = "locked"

    def __str__(self) -> str:
        return str(self.value)


class ListLinksRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"
    STATUS_ASC = "status_asc"
    STATUS_DESC = "status_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListPartnersRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListPopsRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListRoutingPoliciesRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


@dataclass
class Link:
    id: str
    """
    Unique identifier of the link.
    """

    project_id: str
    """
    Project ID.
    """

    organization_id: str
    """
    Organization ID.
    """

    name: str
    """
    Name of the link.
    """

    tags: List[str]
    """
    List of tags associated with the link.
    """

    pop_id: str
    """
    ID of the PoP where the link's corresponding port is located.
    """

    bandwidth_mbps: int
    """
    Rate limited bandwidth of the link.
    """

    partner_id: Optional[str]
    """
    ID of the partner facilitating this link.
    """

    status: LinkStatus
    """
    Status of the link.
    """

    bgp_v4_status: BgpStatus
    """
    Status of the link's BGP IPv4 session.
    """

    bgp_v6_status: BgpStatus
    """
    Status of the link's BGP IPv6 session.
    """

    enable_route_propagation: bool
    """
    Defines whether route propagation is enabled or not. To enable or disable route propagation, use the dedicated endpoint.
    """

    pairing_key: str
    """
    Used to identify a link from a user or partner's point of view.
    """

    region: ScwRegion
    """
    Region of the link.
    """

    vpc_id: Optional[str]
    """
    ID of the Scaleway VPC attached to the link.
    """

    routing_policy_id: Optional[str]
    """
    ID of the routing policy attached to the link.
    """

    created_at: Optional[datetime]
    """
    Creation date of the link.
    """

    updated_at: Optional[datetime]
    """
    Last modification date of the link.
    """

    disapproved_reason: Optional[str]
    """
    Reason given by partner to explain why they did not approve the request for a hosted link.
    """


@dataclass
class Partner:
    id: str
    """
    Unique identifier of the partner.
    """

    name: str
    """
    Name of the partner.
    """

    contact_email: str
    """
    Contact email address of partner.
    """

    logo_url: str
    """
    Image URL of the partner's logo.
    """

    portal_url: str
    """
    URL of the partner's portal.
    """

    created_at: Optional[datetime]
    """
    Creation date of the partner.
    """

    updated_at: Optional[datetime]
    """
    Last modification date of the partner.
    """


@dataclass
class Pop:
    id: str
    """
    Unique identifier of the PoP.
    """

    name: str
    """
    Name of the PoP. It is the common reference of Hosting DC (ex: TH2).
    """

    hosting_provider_name: str
    """
    Name of the PoP's hosting provider, e.g. Telehouse for TH2 or OpCore for DC3.
    """

    address: str
    """
    Physical address of the PoP.
    """

    city: str
    """
    City where PoP is located.
    """

    logo_url: str
    """
    Image URL of the PoP's logo.
    """

    available_link_bandwidths_mbps: List[int]
    """
    Available bandwidth in Mbits/s for future hosted_links from available ports in this PoP.
    """

    region: ScwRegion
    """
    Region of the PoP.
    """


@dataclass
class RoutingPolicy:
    id: str
    """
    Unique identifier of the routing policy.
    """

    project_id: str
    """
    Project ID.
    """

    organization_id: str
    """
    Organization ID.
    """

    name: str
    """
    Name of the routing policy.
    """

    tags: List[str]
    """
    List of tags associated with the routing policy.
    """

    prefix_filter_in: List[str]
    """
    IP prefixes to accept from the peer (ranges of route announcements to accept).
    """

    prefix_filter_out: List[str]
    """
    IP prefix filters to advertise to the peer (ranges of routes to advertise).
    """

    region: ScwRegion
    """
    Region of the routing policy.
    """

    created_at: Optional[datetime]
    """
    Creation date of the routing policy.
    """

    updated_at: Optional[datetime]
    """
    Last modification date of the routing policy.
    """


@dataclass
class AttachRoutingPolicyRequest:
    link_id: str
    """
    ID of the link to attach a routing policy to.
    """

    routing_policy_id: str
    """
    ID of the routing policy to be attached.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class AttachVpcRequest:
    link_id: str
    """
    ID of the link to attach VPC to.
    """

    vpc_id: str
    """
    ID of the VPC to attach.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class CreateLinkRequest:
    name: str
    """
    Name of the link.
    """

    pop_id: str
    """
    PoP (location) where the link will be created.
    """

    bandwidth_mbps: int
    """
    Desired bandwidth for the link. Must be compatible with available link bandwidths and remaining bandwidth capacity of the port.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    ID of the Project to create the link in.
    """

    tags: Optional[List[str]]
    """
    List of tags to apply to the link.
    """

    dedicated: Optional[bool]

    port_id: Optional[str]

    partner_id: Optional[str]


@dataclass
class CreateRoutingPolicyRequest:
    name: str
    """
    Name of the routing policy.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    ID of the Project to create the routing policy in.
    """

    tags: Optional[List[str]]
    """
    List of tags to apply to the routing policy.
    """

    prefix_filter_in: Optional[List[str]]
    """
    IP prefixes to accept from the peer (ranges of route announcements to accept).
    """

    prefix_filter_out: Optional[List[str]]
    """
    IP prefix filters to advertise to the peer (ranges of routes to advertise).
    """


@dataclass
class DeleteLinkRequest:
    link_id: str
    """
    ID of the link to delete.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class DeleteRoutingPolicyRequest:
    routing_policy_id: str
    """
    ID of the routing policy to delete.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class DetachRoutingPolicyRequest:
    link_id: str
    """
    ID of the link to detach a routing policy from.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class DetachVpcRequest:
    link_id: str
    """
    ID of the link to detach the VPC from.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class DisableRoutePropagationRequest:
    link_id: str
    """
    ID of the link on which to disable route propagation.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class EnableRoutePropagationRequest:
    link_id: str
    """
    ID of the link on which to enable route propagation.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class GetLinkRequest:
    link_id: str
    """
    ID of the link to get.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class GetPartnerRequest:
    partner_id: str
    """
    ID of partner to get.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class GetPopRequest:
    pop_id: str
    """
    ID of PoP to get.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class GetRoutingPolicyRequest:
    routing_policy_id: str
    """
    ID of the routing policy to get.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class ListLinksRequest:
    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    order_by: Optional[ListLinksRequestOrderBy]
    """
    Order in which to return results.
    """

    page: Optional[int]
    """
    Page number to return.
    """

    page_size: Optional[int]
    """
    Maximum number of links to return per page.
    """

    project_id: Optional[str]
    """
    Project ID to filter for.
    """

    organization_id: Optional[str]
    """
    Organization ID to filter for.
    """

    name: Optional[str]
    """
    Link name to filter for.
    """

    tags: Optional[List[str]]
    """
    Tags to filter for.
    """

    status: Optional[LinkStatus]
    """
    Link status to filter for.
    """

    bgp_v4_status: Optional[BgpStatus]
    """
    BGP IPv4 status to filter for.
    """

    bgp_v6_status: Optional[BgpStatus]
    """
    BGP IPv6 status to filter for.
    """

    pop_id: Optional[str]
    """
    Filter for links attached to this PoP (via ports).
    """

    bandwidth_mbps: Optional[int]
    """
    Filter for link bandwidth (in Mbps).
    """

    partner_id: Optional[str]
    """
    Filter for links hosted by this partner.
    """

    vpc_id: Optional[str]
    """
    Filter for links attached to this VPC.
    """

    routing_policy_id: Optional[str]
    """
    Filter for links using this routing policy.
    """

    pairing_key: Optional[str]
    """
    Filter for the link with this pairing_key.
    """


@dataclass
class ListLinksResponse:
    links: List[Link]
    """
    List of links on the current page.
    """

    total_count: int
    """
    Total number of links.
    """


@dataclass
class ListPartnersRequest:
    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    order_by: Optional[ListPartnersRequestOrderBy]
    """
    Order in which to return results.
    """

    page: Optional[int]
    """
    Page number to return.
    """

    page_size: Optional[int]
    """
    Maximum number of partners to return per page.
    """

    pop_ids: Optional[List[str]]
    """
    Filter for partners present (offering a port) in one of these PoPs.
    """


@dataclass
class ListPartnersResponse:
    partners: List[Partner]
    """
    List of partners on current page.
    """

    total_count: int
    """
    Total number of partners returned.
    """


@dataclass
class ListPopsRequest:
    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    order_by: Optional[ListPopsRequestOrderBy]
    """
    Order in which to return results.
    """

    page: Optional[int]
    """
    Page number to return.
    """

    page_size: Optional[int]
    """
    Maximum number of PoPs to return per page.
    """

    name: Optional[str]
    """
    PoP name to filter for.
    """

    hosting_provider_name: Optional[str]
    """
    Hosting provider name to filter for.
    """

    partner_id: Optional[str]
    """
    Filter for PoPs hosting an available shared port from this partner.
    """

    link_bandwidth_mbps: Optional[int]
    """
    Filter for PoPs with a shared port allowing this bandwidth size. Note that we cannot guarantee that PoPs returned will have available capacity.
    """


@dataclass
class ListPopsResponse:
    pops: List[Pop]
    """
    List of PoPs on the current page.
    """

    total_count: int
    """
    Total number of PoPs.
    """


@dataclass
class ListRoutingPoliciesRequest:
    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    order_by: Optional[ListRoutingPoliciesRequestOrderBy]
    """
    Order in which to return results.
    """

    page: Optional[int]
    """
    Page number to return.
    """

    page_size: Optional[int]
    """
    Maximum number of routing policies to return per page.
    """

    project_id: Optional[str]
    """
    Project ID to filter for.
    """

    organization_id: Optional[str]
    """
    Organization ID to filter for.
    """

    name: Optional[str]
    """
    Routing policy name to filter for.
    """

    tags: Optional[List[str]]
    """
    Tags to filter for.
    """


@dataclass
class ListRoutingPoliciesResponse:
    routing_policies: List[RoutingPolicy]

    total_count: int


@dataclass
class UpdateLinkRequest:
    link_id: str
    """
    ID of the link to update.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    name: Optional[str]
    """
    Name of the link.
    """

    tags: Optional[List[str]]
    """
    List of tags to apply to the link.
    """


@dataclass
class UpdateRoutingPolicyRequest:
    routing_policy_id: str
    """
    ID of the routing policy to update.
    """

    region: Optional[ScwRegion]
    """
    Region to target. If none is passed will use default region from the config.
    """

    name: Optional[str]
    """
    Name of the routing policy.
    """

    tags: Optional[List[str]]
    """
    List of tags to apply to the routing policy.
    """

    prefix_filter_in: Optional[List[str]]
    """
    IP prefixes to accept from the peer (ranges of route announcements to accept).
    """

    prefix_filter_out: Optional[List[str]]
    """
    IP prefix filters for routes to advertise to the peer (ranges of routes to advertise).
    """



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import ListNamesRequestOrderBy
from .types import ListPinsRequestOrderBy
from .types import ListVolumesRequestOrderBy
from .types import NameStatus
from .content import NAME_TRANSIENT_STATUSES
from .types import PinDetails
from .types import PinStatus
from .content import PIN_TRANSIENT_STATUSES
from .types import PinCIDMeta
from .types import PinCID
from .types import PinInfo
from .types import Name
from .types import Pin
from .types import Volume
from .types import CreatePinByCIDRequest
from .types import CreatePinByURLRequest
from .types import CreateVolumeRequest
from .types import DeletePinRequest
from .types import DeleteVolumeRequest
from .types import ExportKeyNameResponse
from .types import GetPinRequest
from .types import GetVolumeRequest
from .types import IpnsApiCreateNameRequest
from .types import IpnsApiDeleteNameRequest
from .types import IpnsApiExportKeyNameRequest
from .types import IpnsApiGetNameRequest
from .types import IpnsApiImportKeyNameRequest
from .types import IpnsApiListNamesRequest
from .types import IpnsApiUpdateNameRequest
from .types import ListNamesResponse
from .types import ListPinsRequest
from .types import ListPinsResponse
from .types import ListVolumesRequest
from .types import ListVolumesResponse
from .types import ReplacePinRequest
from .types import ReplacePinResponse
from .types import UpdateVolumeRequest
from .api import IpfsV1Alpha1API
from .api import IpfsV1Alpha1IpnsAPI

__all__ = [
    "ListNamesRequestOrderBy",
    "ListPinsRequestOrderBy",
    "ListVolumesRequestOrderBy",
    "NameStatus",
    "NAME_TRANSIENT_STATUSES",
    "PinDetails",
    "PinStatus",
    "PIN_TRANSIENT_STATUSES",
    "PinCIDMeta",
    "PinCID",
    "PinInfo",
    "Name",
    "Pin",
    "Volume",
    "CreatePinByCIDRequest",
    "CreatePinByURLRequest",
    "CreateVolumeRequest",
    "DeletePinRequest",
    "DeleteVolumeRequest",
    "ExportKeyNameResponse",
    "GetPinRequest",
    "GetVolumeRequest",
    "IpnsApiCreateNameRequest",
    "IpnsApiDeleteNameRequest",
    "IpnsApiExportKeyNameRequest",
    "IpnsApiGetNameRequest",
    "IpnsApiImportKeyNameRequest",
    "IpnsApiListNamesRequest",
    "IpnsApiUpdateNameRequest",
    "ListNamesResponse",
    "ListPinsRequest",
    "ListPinsResponse",
    "ListVolumesRequest",
    "ListVolumesResponse",
    "ReplacePinRequest",
    "ReplacePinResponse",
    "UpdateVolumeRequest",
    "IpfsV1Alpha1API",
    "IpfsV1Alpha1IpnsAPI",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from typing import List

from .types import (
    JobRunState,
)

JOB_RUN_TRANSIENT_STATUSES: List[JobRunState] = [
    JobRunState.QUEUED,
    JobRunState.SCHEDULED,
    JobRunState.RUNNING,
]
"""
Lists transient statutes of the enum :class:`JobRunState <JobRunState>`.
"""



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import BrowseSecretsRequestOrderBy
from .types import EphemeralPolicyAction
from .types import ListSecretsRequestOrderBy
from .types import Product
from .types import SecretStatus
from .types import SecretType
from .types import SecretVersionStatus
from .types import EphemeralPolicy
from .types import BrowseSecretsResponseItemFolderDetails
from .types import BrowseSecretsResponseItemSecretDetails
from .types import EphemeralProperties
from .types import BrowseSecretsResponseItem
from .types import SecretVersion
from .types import Secret
from .types import AccessSecretVersionByPathRequest
from .types import AccessSecretVersionRequest
from .types import AccessSecretVersionResponse
from .types import AddSecretOwnerRequest
from .types import BasicCredentials
from .types import BrowseSecretsRequest
from .types import BrowseSecretsResponse
from .types import CreateSecretRequest
from .types import CreateSecretVersionRequest
from .types import DatabaseCredentials
from .types import DeleteSecretRequest
from .types import DeleteSecretVersionRequest
from .types import DisableSecretVersionRequest
from .types import EnableSecretVersionRequest
from .types import GetSecretRequest
from .types import GetSecretVersionRequest
from .types import ListSecretTypesRequest
from .types import ListSecretTypesResponse
from .types import ListSecretVersionsRequest
from .types import ListSecretVersionsResponse
from .types import ListSecretsRequest
from .types import ListSecretsResponse
from .types import ListTagsRequest
from .types import ListTagsResponse
from .types import ProtectSecretRequest
from .types import SSHKey
from .types import UnprotectSecretRequest
from .types import UpdateSecretRequest
from .types import UpdateSecretVersionRequest
from .api import SecretV1Beta1API

__all__ = [
    "BrowseSecretsRequestOrderBy",
    "EphemeralPolicyAction",
    "ListSecretsRequestOrderBy",
    "Product",
    "SecretStatus",
    "SecretType",
    "SecretVersionStatus",
    "EphemeralPolicy",
    "BrowseSecretsResponseItemFolderDetails",
    "BrowseSecretsResponseItemSecretDetails",
    "EphemeralProperties",
    "BrowseSecretsResponseItem",
    "SecretVersion",
    "Secret",
    "AccessSecretVersionByPathRequest",
    "AccessSecretVersionRequest",
    "AccessSecretVersionResponse",
    "AddSecretOwnerRequest",
    "BasicCredentials",
    "BrowseSecretsRequest",
    "BrowseSecretsResponse",
    "CreateSecretRequest",
    "CreateSecretVersionRequest",
    "DatabaseCredentials",
    "DeleteSecretRequest",
    "DeleteSecretVersionRequest",
    "DisableSecretVersionRequest",
    "EnableSecretVersionRequest",
    "GetSecretRequest",
    "GetSecretVersionRequest",
    "ListSecretTypesRequest",
    "ListSecretTypesResponse",
    "ListSecretVersionsRequest",
    "ListSecretVersionsResponse",
    "ListSecretsRequest",
    "ListSecretsResponse",
    "ListTagsRequest",
    "ListTagsResponse",
    "ProtectSecretRequest",
    "SSHKey",
    "UnprotectSecretRequest",
    "UpdateSecretRequest",
    "UpdateSecretVersionRequest",
    "SecretV1Beta1API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from typing import Any, Dict
from dateutil import parser

from scaleway_core.profile import ProfileDefaults
from scaleway_core.bridge import (
    unmarshal_Money,
)
from scaleway_core.utils import (
    OneOfPossibility,
    resolve_one_of,
)
from .types import (
    DomainAction,
    DomainAvailabilityAction,
    DomainDnsAction,
    DatabaseUser,
    Database,
    FtpAccount,
    MailAccount,
    CheckUserOwnsDomainResponse,
    DnsRecord,
    Nameserver,
    DnsRecords,
    AutoConfigDomainDns,
    Domain,
    PlatformControlPanelUrls,
    OfferOption,
    PlatformControlPanel,
    HostingUser,
    Offer,
    Platform,
    Hosting,
    ControlPanel,
    ListControlPanelsResponse,
    ListDatabaseUsersResponse,
    ListDatabasesResponse,
    ListFtpAccountsResponse,
    HostingSummary,
    ListHostingsResponse,
    ListMailAccountsResponse,
    ListOffersResponse,
    Website,
    ListWebsitesResponse,
    ResetHostingPasswordResponse,
    ResourceSummary,
    DomainAvailability,
    SearchDomainsResponse,
    Session,
    DatabaseApiAssignDatabaseUserRequest,
    DatabaseApiChangeDatabaseUserPasswordRequest,
    CreateDatabaseRequestUser,
    DatabaseApiCreateDatabaseRequest,
    DatabaseApiCreateDatabaseUserRequest,
    DatabaseApiUnassignDatabaseUserRequest,
    DnsApiCheckUserOwnsDomainRequest,
    SyncDomainDnsRecordsRequestRecord,
    DnsApiSyncDomainDnsRecordsRequest,
    FtpAccountApiChangeFtpAccountPasswordRequest,
    FtpAccountApiCreateFtpAccountRequest,
    CreateHostingRequestDomainConfiguration,
    OfferOptionRequest,
    HostingApiCreateHostingRequest,
    HostingApiUpdateHostingRequest,
    MailAccountApiChangeMailAccountPasswordRequest,
    MailAccountApiCreateMailAccountRequest,
    MailAccountApiRemoveMailAccountRequest,
)
from ...std.types import (
    LanguageCode as StdLanguageCode,
)


def unmarshal_DatabaseUser(data: Any) -> DatabaseUser:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'DatabaseUser' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("username", None)
    if field is not None:
        args["username"] = field

    field = data.get("databases", None)
    if field is not None:
        args["databases"] = field

    return DatabaseUser(**args)


def unmarshal_Database(data: Any) -> Database:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Database' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("database_name", None)
    if field is not None:
        args["database_name"] = field

    field = data.get("users", None)
    if field is not None:
        args["users"] = field

    return Database(**args)


def unmarshal_FtpAccount(data: Any) -> FtpAccount:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'FtpAccount' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("username", None)
    if field is not None:
        args["username"] = field

    field = data.get("path", None)
    if field is not None:
        args["path"] = field

    return FtpAccount(**args)


def unmarshal_MailAccount(data: Any) -> MailAccount:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'MailAccount' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("domain", None)
    if field is not None:
        args["domain"] = field

    field = data.get("username", None)
    if field is not None:
        args["username"] = field

    return MailAccount(**args)


def unmarshal_CheckUserOwnsDomainResponse(data: Any) -> CheckUserOwnsDomainResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'CheckUserOwnsDomainResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("owns_domain", None)
    if field is not None:
        args["owns_domain"] = field

    return CheckUserOwnsDomainResponse(**args)


def unmarshal_DnsRecord(data: Any) -> DnsRecord:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'DnsRecord' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("type", None)
    if field is not None:
        args["type_"] = field

    field = data.get("ttl", None)
    if field is not None:
        args["ttl"] = field

    field = data.get("value", None)
    if field is not None:
        args["value"] = field

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    field = data.get("raw_data", None)
    if field is not None:
        args["raw_data"] = field

    field = data.get("priority", None)
    if field is not None:
        args["priority"] = field
    else:
        args["priority"] = None

    return DnsRecord(**args)


def unmarshal_Nameserver(data: Any) -> Nameserver:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Nameserver' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("hostname", None)
    if field is not None:
        args["hostname"] = field

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    field = data.get("is_default", None)
    if field is not None:
        args["is_default"] = field

    return Nameserver(**args)


def unmarshal_DnsRecords(data: Any) -> DnsRecords:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'DnsRecords' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("records", None)
    if field is not None:
        args["records"] = (
            [unmarshal_DnsRecord(v) for v in field] if field is not None else None
        )

    field = data.get("name_servers", None)
    if field is not None:
        args["name_servers"] = (
            [unmarshal_Nameserver(v) for v in field] if field is not None else None
        )

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    field = data.get("dns_config", None)
    if field is not None:
        args["dns_config"] = (
            [DomainDnsAction(v) for v in field] if field is not None else None
        )

    return DnsRecords(**args)


def unmarshal_AutoConfigDomainDns(data: Any) -> AutoConfigDomainDns:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'AutoConfigDomainDns' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("nameservers", None)
    if field is not None:
        args["nameservers"] = field

    field = data.get("web_records", None)
    if field is not None:
        args["web_records"] = field

    field = data.get("mail_records", None)
    if field is not None:
        args["mail_records"] = field

    field = data.get("all_records", None)
    if field is not None:
        args["all_records"] = field

    return AutoConfigDomainDns(**args)


def unmarshal_Domain(data: Any) -> Domain:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Domain' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    field = data.get("owner", None)
    if field is not None:
        args["owner"] = field

    field = data.get("available_actions", None)
    if field is not None:
        args["available_actions"] = (
            [DomainAction(v) for v in field] if field is not None else None
        )

    field = data.get("available_dns_actions", None)
    if field is not None:
        args["available_dns_actions"] = (
            [DomainDnsAction(v) for v in field] if field is not None else None
        )
    else:
        args["available_dns_actions"] = None

    field = data.get("auto_config_domain_dns", None)
    if field is not None:
        args["auto_config_domain_dns"] = unmarshal_AutoConfigDomainDns(field)
    else:
        args["auto_config_domain_dns"] = None

    return Domain(**args)


def unmarshal_PlatformControlPanelUrls(data: Any) -> PlatformControlPanelUrls:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'PlatformControlPanelUrls' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("dashboard", None)
    if field is not None:
        args["dashboard"] = field

    field = data.get("webmail", None)
    if field is not None:
        args["webmail"] = field

    return PlatformControlPanelUrls(**args)


def unmarshal_OfferOption(data: Any) -> OfferOption:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'OfferOption' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("billing_operation_path", None)
    if field is not None:
        args["billing_operation_path"] = field

    field = data.get("min_value", None)
    if field is not None:
        args["min_value"] = field

    field = data.get("current_value", None)
    if field is not None:
        args["current_value"] = field

    field = data.get("max_value", None)
    if field is not None:
        args["max_value"] = field

    field = data.get("quota_warning", None)
    if field is not None:
        args["quota_warning"] = field

    field = data.get("price", None)
    if field is not None:
        args["price"] = unmarshal_Money(field)
    else:
        args["price"] = None

    return OfferOption(**args)


def unmarshal_PlatformControlPanel(data: Any) -> PlatformControlPanel:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'PlatformControlPanel' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("urls", None)
    if field is not None:
        args["urls"] = unmarshal_PlatformControlPanelUrls(field)
    else:
        args["urls"] = None

    return PlatformControlPanel(**args)


def unmarshal_HostingUser(data: Any) -> HostingUser:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'HostingUser' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("username", None)
    if field is not None:
        args["username"] = field

    field = data.get("contact_email", None)
    if field is not None:
        args["contact_email"] = field

    field = data.get("one_time_password", None)
    if field is not None:
        args["one_time_password"] = field
    else:
        args["one_time_password"] = None

    return HostingUser(**args)


def unmarshal_Offer(data: Any) -> Offer:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Offer' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("billing_operation_path", None)
    if field is not None:
        args["billing_operation_path"] = field

    field = data.get("options", None)
    if field is not None:
        args["options"] = (
            [unmarshal_OfferOption(v) for v in field] if field is not None else None
        )

    field = data.get("available", None)
    if field is not None:
        args["available"] = field

    field = data.get("control_panel_name", None)
    if field is not None:
        args["control_panel_name"] = field

    field = data.get("end_of_life", None)
    if field is not None:
        args["end_of_life"] = field

    field = data.get("quota_warning", None)
    if field is not None:
        args["quota_warning"] = field

    field = data.get("price", None)
    if field is not None:
        args["price"] = unmarshal_Money(field)
    else:
        args["price"] = None

    return Offer(**args)


def unmarshal_Platform(data: Any) -> Platform:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Platform' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("hostname", None)
    if field is not None:
        args["hostname"] = field

    field = data.get("number", None)
    if field is not None:
        args["number"] = field

    field = data.get("group_name", None)
    if field is not None:
        args["group_name"] = field

    field = data.get("ipv4", None)
    if field is not None:
        args["ipv4"] = field

    field = data.get("ipv6", None)
    if field is not None:
        args["ipv6"] = field

    field = data.get("control_panel", None)
    if field is not None:
        args["control_panel"] = unmarshal_PlatformControlPanel(field)
    else:
        args["control_panel"] = None

    return Platform(**args)


def unmarshal_Hosting(data: Any) -> Hosting:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Hosting' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("project_id", None)
    if field is not None:
        args["project_id"] = field

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    field = data.get("domain", None)
    if field is not None:
        args["domain"] = field

    field = data.get("tags", None)
    if field is not None:
        args["tags"] = field

    field = data.get("ipv4", None)
    if field is not None:
        args["ipv4"] = field

    field = data.get("updated_at", None)
    if field is not None:
        args["updated_at"] = parser.isoparse(field) if isinstance(field, str) else field
    else:
        args["updated_at"] = None

    field = data.get("created_at", None)
    if field is not None:
        args["created_at"] = parser.isoparse(field) if isinstance(field, str) else field
    else:
        args["created_at"] = None

    field = data.get("protected", None)
    if field is not None:
        args["protected"] = field

    field = data.get("domain_status", None)
    if field is not None:
        args["domain_status"] = field

    field = data.get("region", None)
    if field is not None:
        args["region"] = field

    field = data.get("offer", None)
    if field is not None:
        args["offer"] = unmarshal_Offer(field)
    else:
        args["offer"] = None

    field = data.get("platform", None)
    if field is not None:
        args["platform"] = unmarshal_Platform(field)
    else:
        args["platform"] = None

    field = data.get("dns_status", None)
    if field is not None:
        args["dns_status"] = field
    else:
        args["dns_status"] = None

    field = data.get("user", None)
    if field is not None:
        args["user"] = unmarshal_HostingUser(field)
    else:
        args["user"] = None

    return Hosting(**args)


def unmarshal_ControlPanel(data: Any) -> ControlPanel:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ControlPanel' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("available", None)
    if field is not None:
        args["available"] = field

    field = data.get("logo_url", None)
    if field is not None:
        args["logo_url"] = field

    field = data.get("available_languages", None)
    if field is not None:
        args["available_languages"] = (
            [StdLanguageCode(v) for v in field] if field is not None else None
        )

    return ControlPanel(**args)


def unmarshal_ListControlPanelsResponse(data: Any) -> ListControlPanelsResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListControlPanelsResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("control_panels", None)
    if field is not None:
        args["control_panels"] = (
            [unmarshal_ControlPanel(v) for v in field] if field is not None else None
        )

    return ListControlPanelsResponse(**args)


def unmarshal_ListDatabaseUsersResponse(data: Any) -> ListDatabaseUsersResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListDatabaseUsersResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("users", None)
    if field is not None:
        args["users"] = (
            [unmarshal_DatabaseUser(v) for v in field] if field is not None else None
        )

    return ListDatabaseUsersResponse(**args)


def unmarshal_ListDatabasesResponse(data: Any) -> ListDatabasesResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListDatabasesResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("databases", None)
    if field is not None:
        args["databases"] = (
            [unmarshal_Database(v) for v in field] if field is not None else None
        )

    return ListDatabasesResponse(**args)


def unmarshal_ListFtpAccountsResponse(data: Any) -> ListFtpAccountsResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListFtpAccountsResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("ftp_accounts", None)
    if field is not None:
        args["ftp_accounts"] = (
            [unmarshal_FtpAccount(v) for v in field] if field is not None else None
        )

    return ListFtpAccountsResponse(**args)


def unmarshal_HostingSummary(data: Any) -> HostingSummary:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'HostingSummary' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("project_id", None)
    if field is not None:
        args["project_id"] = field

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    field = data.get("domain", None)
    if field is not None:
        args["domain"] = field

    field = data.get("protected", None)
    if field is not None:
        args["protected"] = field

    field = data.get("offer_name", None)
    if field is not None:
        args["offer_name"] = field

    field = data.get("domain_status", None)
    if field is not None:
        args["domain_status"] = field

    field = data.get("region", None)
    if field is not None:
        args["region"] = field

    field = data.get("created_at", None)
    if field is not None:
        args["created_at"] = parser.isoparse(field) if isinstance(field, str) else field
    else:
        args["created_at"] = None

    field = data.get("updated_at", None)
    if field is not None:
        args["updated_at"] = parser.isoparse(field) if isinstance(field, str) else field
    else:
        args["updated_at"] = None

    field = data.get("dns_status", None)
    if field is not None:
        args["dns_status"] = field
    else:
        args["dns_status"] = None

    return HostingSummary(**args)


def unmarshal_ListHostingsResponse(data: Any) -> ListHostingsResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListHostingsResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("hostings", None)
    if field is not None:
        args["hostings"] = (
            [unmarshal_HostingSummary(v) for v in field] if field is not None else None
        )

    return ListHostingsResponse(**args)


def unmarshal_ListMailAccountsResponse(data: Any) -> ListMailAccountsResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListMailAccountsResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("mail_accounts", None)
    if field is not None:
        args["mail_accounts"] = (
            [unmarshal_MailAccount(v) for v in field] if field is not None else None
        )

    return ListMailAccountsResponse(**args)


def unmarshal_ListOffersResponse(data: Any) -> ListOffersResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListOffersResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("offers", None)
    if field is not None:
        args["offers"] = (
            [unmarshal_Offer(v) for v in field] if field is not None else None
        )

    return ListOffersResponse(**args)


def unmarshal_Website(data: Any) -> Website:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Website' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("domain", None)
    if field is not None:
        args["domain"] = field

    field = data.get("path", None)
    if field is not None:
        args["path"] = field

    field = data.get("ssl_status", None)
    if field is not None:
        args["ssl_status"] = field

    return Website(**args)


def unmarshal_ListWebsitesResponse(data: Any) -> ListWebsitesResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListWebsitesResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("websites", None)
    if field is not None:
        args["websites"] = (
            [unmarshal_Website(v) for v in field] if field is not None else None
        )

    return ListWebsitesResponse(**args)


def unmarshal_ResetHostingPasswordResponse(data: Any) -> ResetHostingPasswordResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ResetHostingPasswordResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("one_time_password", None)
    if field is not None:
        args["one_time_password"] = field

    return ResetHostingPasswordResponse(**args)


def unmarshal_ResourceSummary(data: Any) -> ResourceSummary:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ResourceSummary' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("databases_count", None)
    if field is not None:
        args["databases_count"] = field

    field = data.get("mail_accounts_count", None)
    if field is not None:
        args["mail_accounts_count"] = field

    field = data.get("ftp_accounts_count", None)
    if field is not None:
        args["ftp_accounts_count"] = field

    field = data.get("websites_count", None)
    if field is not None:
        args["websites_count"] = field

    return ResourceSummary(**args)


def unmarshal_DomainAvailability(data: Any) -> DomainAvailability:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'DomainAvailability' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("zone_name", None)
    if field is not None:
        args["zone_name"] = field

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    field = data.get("available_actions", None)
    if field is not None:
        args["available_actions"] = (
            [DomainAvailabilityAction(v) for v in field] if field is not None else None
        )

    field = data.get("can_create_hosting", None)
    if field is not None:
        args["can_create_hosting"] = field

    field = data.get("price", None)
    if field is not None:
        args["price"] = unmarshal_Money(field)
    else:
        args["price"] = None

    return DomainAvailability(**args)


def unmarshal_SearchDomainsResponse(data: Any) -> SearchDomainsResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'SearchDomainsResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("domains_available", None)
    if field is not None:
        args["domains_available"] = (
            [unmarshal_DomainAvailability(v) for v in field]
            if field is not None
            else None
        )

    return SearchDomainsResponse(**args)


def unmarshal_Session(data: Any) -> Session:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Session' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("url", None)
    if field is not None:
        args["url"] = field

    return Session(**args)


def marshal_DatabaseApiAssignDatabaseUserRequest(
    request: DatabaseApiAssignDatabaseUserRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.username is not None:
        output["username"] = request.username

    return output


def marshal_DatabaseApiChangeDatabaseUserPasswordRequest(
    request: DatabaseApiChangeDatabaseUserPasswordRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.password is not None:
        output["password"] = request.password

    return output


def marshal_CreateDatabaseRequestUser(
    request: CreateDatabaseRequestUser,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.username is not None:
        output["username"] = request.username

    if request.password is not None:
        output["password"] = request.password

    return output


def marshal_DatabaseApiCreateDatabaseRequest(
    request: DatabaseApiCreateDatabaseRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}
    output.update(
        resolve_one_of(
            [
                OneOfPossibility("new_user", request.new_user),
                OneOfPossibility("existing_username", request.existing_username),
            ]
        ),
    )

    if request.database_name is not None:
        output["database_name"] = request.database_name

    return output


def marshal_DatabaseApiCreateDatabaseUserRequest(
    request: DatabaseApiCreateDatabaseUserRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.username is not None:
        output["username"] = request.username

    if request.password is not None:
        output["password"] = request.password

    return output


def marshal_DatabaseApiUnassignDatabaseUserRequest(
    request: DatabaseApiUnassignDatabaseUserRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.username is not None:
        output["username"] = request.username

    return output


def marshal_DnsApiCheckUserOwnsDomainRequest(
    request: DnsApiCheckUserOwnsDomainRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.project_id is not None:
        output["project_id"] = request.project_id or defaults.default_project_id

    return output


def marshal_AutoConfigDomainDns(
    request: AutoConfigDomainDns,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.nameservers is not None:
        output["nameservers"] = request.nameservers

    if request.web_records is not None:
        output["web_records"] = request.web_records

    if request.mail_records is not None:
        output["mail_records"] = request.mail_records

    if request.all_records is not None:
        output["all_records"] = request.all_records

    return output


def marshal_SyncDomainDnsRecordsRequestRecord(
    request: SyncDomainDnsRecordsRequestRecord,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.name is not None:
        output["name"] = request.name

    if request.type_ is not None:
        output["type"] = str(request.type_)

    return output


def marshal_DnsApiSyncDomainDnsRecordsRequest(
    request: DnsApiSyncDomainDnsRecordsRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.update_web_records is not None:
        output["update_web_records"] = request.update_web_records

    if request.update_mail_records is not None:
        output["update_mail_records"] = request.update_mail_records

    if request.update_all_records is not None:
        output["update_all_records"] = request.update_all_records

    if request.update_nameservers is not None:
        output["update_nameservers"] = request.update_nameservers

    if request.custom_records is not None:
        output["custom_records"] = [
            marshal_SyncDomainDnsRecordsRequestRecord(item, defaults)
            for item in request.custom_records
        ]

    if request.auto_config_domain_dns is not None:
        output["auto_config_domain_dns"] = marshal_AutoConfigDomainDns(
            request.auto_config_domain_dns, defaults
        )

    return output


def marshal_FtpAccountApiChangeFtpAccountPasswordRequest(
    request: FtpAccountApiChangeFtpAccountPasswordRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.password is not None:
        output["password"] = request.password

    return output


def marshal_FtpAccountApiCreateFtpAccountRequest(
    request: FtpAccountApiCreateFtpAccountRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.username is not None:
        output["username"] = request.username

    if request.path is not None:
        output["path"] = request.path

    if request.password is not None:
        output["password"] = request.password

    return output


def marshal_CreateHostingRequestDomainConfiguration(
    request: CreateHostingRequestDomainConfiguration,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.update_nameservers is not None:
        output["update_nameservers"] = request.update_nameservers

    if request.update_web_record is not None:
        output["update_web_record"] = request.update_web_record

    if request.update_mail_record is not None:
        output["update_mail_record"] = request.update_mail_record

    if request.update_all_records is not None:
        output["update_all_records"] = request.update_all_records

    return output


def marshal_OfferOptionRequest(
    request: OfferOptionRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.id is not None:
        output["id"] = request.id

    if request.quantity is not None:
        output["quantity"] = request.quantity

    return output


def marshal_HostingApiCreateHostingRequest(
    request: HostingApiCreateHostingRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.offer_id is not None:
        output["offer_id"] = request.offer_id

    if request.email is not None:
        output["email"] = request.email

    if request.domain is not None:
        output["domain"] = request.domain

    if request.project_id is not None:
        output["project_id"] = request.project_id or defaults.default_project_id

    if request.tags is not None:
        output["tags"] = request.tags

    if request.offer_options is not None:
        output["offer_options"] = [
            marshal_OfferOptionRequest(item, defaults) for item in request.offer_options
        ]

    if request.language is not None:
        output["language"] = str(request.language)

    if request.domain_configuration is not None:
        output["domain_configuration"] = (
            marshal_CreateHostingRequestDomainConfiguration(
                request.domain_configuration, defaults
            )
        )

    if request.skip_welcome_email is not None:
        output["skip_welcome_email"] = request.skip_welcome_email

    if request.auto_config_domain_dns is not None:
        output["auto_config_domain_dns"] = marshal_AutoConfigDomainDns(
            request.auto_config_domain_dns, defaults
        )

    return output


def marshal_HostingApiUpdateHostingRequest(
    request: HostingApiUpdateHostingRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.email is not None:
        output["email"] = request.email

    if request.tags is not None:
        output["tags"] = request.tags

    if request.offer_options is not None:
        output["offer_options"] = [
            marshal_OfferOptionRequest(item, defaults) for item in request.offer_options
        ]

    if request.offer_id is not None:
        output["offer_id"] = request.offer_id

    if request.protected is not None:
        output["protected"] = request.protected

    return output


def marshal_MailAccountApiChangeMailAccountPasswordRequest(
    request: MailAccountApiChangeMailAccountPasswordRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.domain is not None:
        output["domain"] = request.domain

    if request.username is not None:
        output["username"] = request.username

    if request.password is not None:
        output["password"] = request.password

    return output


def marshal_MailAccountApiCreateMailAccountRequest(
    request: MailAccountApiCreateMailAccountRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.domain is not None:
        output["domain"] = request.domain

    if request.username is not None:
        output["username"] = request.username

    if request.password is not None:
        output["password"] = request.password

    return output


def marshal_MailAccountApiRemoveMailAccountRequest(
    request: MailAccountApiRemoveMailAccountRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.domain is not None:
        output["domain"] = request.domain

    if request.username is not None:
        output["username"] = request.username

    return output



import sys
import unittest
import logging
from typing import Dict

from scaleway_core.client import Client
from .custom_api import InstanceUtilsV1API

logger = logging.getLogger()
logger.level = logging.DEBUG
stream_handler = logging.StreamHandler(sys.stdout)
logger.addHandler(stream_handler)


class TestServerUserData(unittest.TestCase):
    def setUp(self) -> None:
        self.client = Client()
        self.instance_api = InstanceUtilsV1API(self.client, bypass_validation=True)
        self.server = self.instance_api._create_server(
            commercial_type="DEV1-S",
            zone="fr-par-1",
            image="ubuntu_jammy",
            name="my-server-web",
            volumes={},
        )

    @unittest.skip("API Test is not up")
    def test_set_and_get_server_user_data(self) -> None:
        if self.server is None or self.server.server is None:
            self.fail("Server setup failed.")
        key = "first key"
        content = b"\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x10"
        self.instance_api.set_server_user_data(
            server_id=self.server.server.id, key=key, content=content
        )
        user_data = self.instance_api.get_server_user_data(
            server_id=self.server.server.id, key=key
        )
        self.assertIsNotNone(user_data)

    @unittest.skip("API Test is not up")
    def test_set_and_get_all_user_data(self) -> None:
        if self.server is None or self.server.server is None:
            self.fail("Server setup failed.")
        key = "first key"
        content = b"content first key"
        key_bis = "second key"
        content_bis = b"test content"
        another_key = "third key"
        another_content = b"another content to test"

        user_data: Dict[str, bytes] = {
            key_bis: content_bis,
            another_key: another_content,
            key: content,
        }
        self.instance_api.set_all_server_user_data(
            server_id=self.server.server.id, user_data=user_data
        )
        response = self.instance_api.get_all_server_user_data(
            server_id=self.server.server.id
        )
        self.assertIsNotNone(response)
